Probe Environments
==================

For more information on how to use probe environments, see :ref:`Debugging RL<debugging_rl>`.

Single-agent probe environments
-------------------------------

.. _single_ConstantRewardEnv:

.. autoclass:: agilerl.utils.probe_envs.ConstantRewardEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs.py
    :language: python
    :pyobject: ConstantRewardEnv

.. _single_ConstantRewardImageEnv:

.. autoclass:: agilerl.utils.probe_envs.ConstantRewardImageEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs.py
    :language: python
    :pyobject: ConstantRewardImageEnv

.. _single_ConstantRewardContActionsEnv:

.. autoclass:: agilerl.utils.probe_envs.ConstantRewardContActionsEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs.py
    :language: python
    :pyobject: ConstantRewardContActionsEnv

.. _single_ConstantRewardContActionsImageEnv:

.. autoclass:: agilerl.utils.probe_envs.ConstantRewardContActionsImageEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs.py
    :language: python
    :pyobject: ConstantRewardContActionsImageEnv

.. _single_ObsDependentRewardEnv:

.. autoclass:: agilerl.utils.probe_envs.ObsDependentRewardEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs.py
    :language: python
    :pyobject: ObsDependentRewardEnv

.. _single_ObsDependentRewardImageEnv:

.. autoclass:: agilerl.utils.probe_envs.ObsDependentRewardImageEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs.py
    :language: python
    :pyobject: ObsDependentRewardImageEnv

.. _single_ObsDependentRewardContActionsEnv:

.. autoclass:: agilerl.utils.probe_envs.ObsDependentRewardContActionsEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs.py
    :language: python
    :pyobject: ObsDependentRewardContActionsEnv

.. _single_ObsDependentRewardContActionsImageEnv:

.. autoclass:: agilerl.utils.probe_envs.ObsDependentRewardContActionsImageEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs.py
    :language: python
    :pyobject: ObsDependentRewardContActionsImageEnv

.. _single_DiscountedRewardEnv:

.. autoclass:: agilerl.utils.probe_envs.DiscountedRewardEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs.py
    :language: python
    :pyobject: DiscountedRewardEnv

.. _single_DiscountedRewardImageEnv:

.. autoclass:: agilerl.utils.probe_envs.DiscountedRewardImageEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs.py
    :language: python
    :pyobject: DiscountedRewardImageEnv

.. _single_DiscountedRewardContActionsEnv:

.. autoclass:: agilerl.utils.probe_envs.DiscountedRewardContActionsEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs.py
    :language: python
    :pyobject: DiscountedRewardContActionsEnv

.. _single_DiscountedRewardContActionsImageEnv:

.. autoclass:: agilerl.utils.probe_envs.DiscountedRewardContActionsImageEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs.py
    :language: python
    :pyobject: DiscountedRewardContActionsImageEnv

.. _single_FixedObsPolicyEnv:

.. autoclass:: agilerl.utils.probe_envs.FixedObsPolicyEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs.py
    :language: python
    :pyobject: FixedObsPolicyEnv

.. _single_FixedObsPolicyImageEnv:

.. autoclass:: agilerl.utils.probe_envs.FixedObsPolicyImageEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs.py
    :language: python
    :pyobject: FixedObsPolicyImageEnv

.. _single_FixedObsPolicyContActionsEnv:

.. autoclass:: agilerl.utils.probe_envs.FixedObsPolicyContActionsEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs.py
    :language: python
    :pyobject: FixedObsPolicyContActionsEnv

.. _single_FixedObsPolicyContActionsImageEnv:

.. autoclass:: agilerl.utils.probe_envs.FixedObsPolicyContActionsImageEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs.py
    :language: python
    :pyobject: FixedObsPolicyContActionsImageEnv

.. _single_PolicyEnv:

.. autoclass:: agilerl.utils.probe_envs.PolicyEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs.py
    :language: python
    :pyobject: PolicyEnv

.. _single_PolicyImageEnv:

.. autoclass:: agilerl.utils.probe_envs.PolicyImageEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs.py
    :language: python
    :pyobject: PolicyImageEnv

.. _single_PolicyContActionsEnv:

.. autoclass:: agilerl.utils.probe_envs.PolicyContActionsEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs.py
    :language: python
    :pyobject: PolicyContActionsEnv

.. _single_PolicyContActionsImageEnvSimple:

.. autoclass:: agilerl.utils.probe_envs.PolicyContActionsImageEnvSimple

.. literalinclude:: ../../../agilerl/utils/probe_envs.py
    :language: python
    :pyobject: PolicyContActionsImageEnvSimple

.. _single_PolicyContActionsImageEnv:

.. autoclass:: agilerl.utils.probe_envs.PolicyContActionsImageEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs.py
    :language: python
    :pyobject: PolicyContActionsImageEnv

.. _single_check_q_learning_with_probe_env:

.. autofunction:: agilerl.utils.probe_envs.check_q_learning_with_probe_env

.. literalinclude:: ../../../agilerl/utils/probe_envs.py
    :language: python
    :pyobject: check_q_learning_with_probe_env

.. _single_check_policy_q_learning_with_probe_env:

.. autofunction:: agilerl.utils.probe_envs.check_policy_q_learning_with_probe_env

.. literalinclude:: ../../../agilerl/utils/probe_envs.py
    :language: python
    :pyobject: check_policy_q_learning_with_probe_env

.. _single_check_policy_on_policy_with_probe_env:

.. autofunction:: agilerl.utils.probe_envs.check_policy_on_policy_with_probe_env

.. literalinclude:: ../../../agilerl/utils/probe_envs.py
    :language: python
    :pyobject: check_policy_on_policy_with_probe_env

Multi-agent probe environments
------------------------------

.. _multi_ConstantRewardEnv:

.. autoclass:: agilerl.utils.probe_envs_ma.ConstantRewardEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs_ma.py
    :language: python
    :pyobject: ConstantRewardEnv

.. _multi_ConstantRewardImageEnv:

.. autoclass:: agilerl.utils.probe_envs_ma.ConstantRewardImageEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs_ma.py
    :language: python
    :pyobject: ConstantRewardImageEnv

.. _multi_ConstantRewardContActionsEnv:

.. autoclass:: agilerl.utils.probe_envs_ma.ConstantRewardContActionsEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs_ma.py
    :language: python
    :pyobject: ConstantRewardContActionsEnv

.. _multi_ConstantRewardContActionsImageEnv:

.. autoclass:: agilerl.utils.probe_envs_ma.ConstantRewardContActionsImageEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs_ma.py
    :language: python
    :pyobject: ConstantRewardContActionsImageEnv

.. _multi_ObsDependentRewardEnv:

.. autoclass:: agilerl.utils.probe_envs_ma.ObsDependentRewardEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs_ma.py
    :language: python
    :pyobject: ObsDependentRewardEnv

.. _multi_ObsDependentRewardImageEnv:

.. autoclass:: agilerl.utils.probe_envs_ma.ObsDependentRewardImageEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs_ma.py
    :language: python
    :pyobject: ObsDependentRewardImageEnv

.. _multi_ObsDependentRewardContActionsEnv:

.. autoclass:: agilerl.utils.probe_envs_ma.ObsDependentRewardContActionsEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs_ma.py
    :language: python
    :pyobject: ObsDependentRewardContActionsEnv

.. _multi_ObsDependentRewardContActionsImageEnv:

.. autoclass:: agilerl.utils.probe_envs_ma.ObsDependentRewardContActionsImageEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs_ma.py
    :language: python
    :pyobject: ObsDependentRewardContActionsImageEnv

.. _multi_DiscountedRewardEnv:

.. autoclass:: agilerl.utils.probe_envs_ma.DiscountedRewardEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs_ma.py
    :language: python
    :pyobject: DiscountedRewardEnv

.. _multi_DiscountedRewardImageEnv:

.. autoclass:: agilerl.utils.probe_envs_ma.DiscountedRewardImageEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs_ma.py
    :language: python
    :pyobject: DiscountedRewardImageEnv

.. _multi_DiscountedRewardContActionsEnv:

.. autoclass:: agilerl.utils.probe_envs_ma.DiscountedRewardContActionsEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs_ma.py
    :language: python
    :pyobject: DiscountedRewardContActionsEnv

.. _multi_DiscountedRewardContActionsImageEnv:

.. autoclass:: agilerl.utils.probe_envs_ma.DiscountedRewardContActionsImageEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs_ma.py
    :language: python
    :pyobject: DiscountedRewardContActionsImageEnv

.. _multi_FixedObsPolicyEnv:

.. autoclass:: agilerl.utils.probe_envs_ma.FixedObsPolicyEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs_ma.py
    :language: python
    :pyobject: FixedObsPolicyEnv

.. _multi_FixedObsPolicyImageEnv:

.. autoclass:: agilerl.utils.probe_envs_ma.FixedObsPolicyImageEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs_ma.py
    :language: python
    :pyobject: FixedObsPolicyImageEnv

.. _multi_FixedObsPolicyContActionsEnv:

.. autoclass:: agilerl.utils.probe_envs_ma.FixedObsPolicyContActionsEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs_ma.py
    :language: python
    :pyobject: FixedObsPolicyContActionsEnv

.. _multi_FixedObsPolicyContActionsImageEnv:

.. autoclass:: agilerl.utils.probe_envs_ma.FixedObsPolicyContActionsImageEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs_ma.py
    :language: python
    :pyobject: FixedObsPolicyContActionsImageEnv

.. _multi_PolicyEnv:

.. autoclass:: agilerl.utils.probe_envs_ma.PolicyEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs_ma.py
    :language: python
    :pyobject: PolicyEnv

.. _multi_PolicyImageEnv:

.. autoclass:: agilerl.utils.probe_envs_ma.PolicyImageEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs_ma.py
    :language: python
    :pyobject: PolicyImageEnv

.. _multi_PolicyContActionsEnv:

.. autoclass:: agilerl.utils.probe_envs_ma.PolicyContActionsEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs_ma.py
    :language: python
    :pyobject: PolicyContActionsEnv

.. _multi_PolicyContActionsImageEnv:

.. autoclass:: agilerl.utils.probe_envs_ma.PolicyContActionsImageEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs_ma.py
    :language: python
    :pyobject: PolicyContActionsImageEnv

.. _multi_MultiPolicyEnv:

.. autoclass:: agilerl.utils.probe_envs_ma.MultiPolicyEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs_ma.py
    :language: python
    :pyobject: MultiPolicyEnv

.. _multi_MultiPolicyImageEnv:

.. autoclass:: agilerl.utils.probe_envs_ma.MultiPolicyImageEnv

.. literalinclude:: ../../../agilerl/utils/probe_envs_ma.py
    :language: python
    :pyobject: MultiPolicyImageEnv

.. _multi_check_policy_q_learning_with_probe_env:

.. autofunction:: agilerl.utils.probe_envs_ma.check_policy_q_learning_with_probe_env

.. literalinclude:: ../../../agilerl/utils/probe_envs_ma.py
    :language: python
    :pyobject: check_policy_q_learning_with_probe_env
